{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for SQL.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/sql.xml and 'make bootstrap'.
module Skylighting.Syntax.Sql (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for SQL.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asql.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolFlow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\210\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTACOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nADD_MONTHS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASCII\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bASCIISTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTASIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTATAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQATAN2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAVG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBFILENAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBIN_TO_NUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCARDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCEIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCHARTOROWID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCOALESCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOLLECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCONCAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONVERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCORR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCORR_K\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCORR_S\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOSH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCOVAR_POP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCOVAR_SAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCUME_DIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_DATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CURRENT_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXCV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDBTIMEZONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDECODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDECOMPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDENSE_RANK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDEPTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDEREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDUMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEMPTY_BLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEMPTY_CLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEXISTSNODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEXP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTRACT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEXTRACTVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIRST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFIRST_VALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFROM_TZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGREATEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGROUP_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGROUPING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGROUPING_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHEXTORAW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINITCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINSTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSTRB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLAG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLAST_DAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLAST_VALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLEAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLEAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLENGTHB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLNNVL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLOCALTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMAKE_REF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMEDIAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMONTHS_BETWEEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNANVL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNEW_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNEXT_DAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4NLS_CHARSET_DECL_LEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONLS_CHARSET_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENLS_CHARSET_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNLS_INITCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNLS_LOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNLS_UPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNLSSORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNTILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNULLIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINUMTODSINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINUMTOYMINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNVL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNVL2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bORA_HASH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nORA_ROWSCN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPERCENT_RANK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPERCENTILE_CONT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPERCENTILE_DISC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPOWERMULTISET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSPOWERMULTISET_BY_CARDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPRESENTNNV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPRESENTV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRANK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRATIO_TO_REPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRAWTOHEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRAWTONHEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREFTOHEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fREGEXP_INSTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREGEXP_LIKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOREGEXP_REPLACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rREGEXP_SUBSTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREGR_SLOPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOREGR_INTERCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREGR_COUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREGR_R2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tREGR_AVGX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tREGR_AVGY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREGR_SXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREGR_SYY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREGR_SXY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tREMAINDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQROUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nROW_NUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vROWIDTOCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fROWIDTONCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESCN_TO_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISESSIONTIMEZONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSINH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSOUNDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSQRT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3STATS_BINOMIAL_TEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSTATS_CROSSTAB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSTATS_F_TEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSTATS_KS_TEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSTATS_MODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSTATS_MW_TEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3STATS_ONE_WAY_ANOVA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESTATS_T_TEST_ONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3STATS_T_TEST_PAIRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2STATS_T_TEST_INDEP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3STATS_T_TEST_INDEPU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSTATS_WSR_TEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTDDEV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSTDDEV_POP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSTDDEV_SAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBSTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSUBSTRB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SYS_CONNECT_BY_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSYS_CONTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSYS_DBURIGEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISYS_EXTRACT_UTC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSYS_GUID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSYS_TYPEID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSYS_XMLAGG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSYS_XMLGEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSYSDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSYSTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTANH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETIMESTAMP_TO_SCN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETO_BINARY_DOUBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITO_BINARY_FLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTO_CHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTO_CLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTO_DATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTO_DSINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTO_LOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTO_MULTI_BYTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTO_NCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTO_NCLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTO_NUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTO_SINGLE_BYTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTO_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITO_TIMESTAMP_TZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTO_YMINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTRANSLATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTREAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTZ_OFFSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXUID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNISTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUPDATEXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTUSER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUSERENV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVAR_POP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVAR_SAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVARIANCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWIDTH_BUCKET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKXMLAGG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXMLCOLATTVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLCONCAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nXMLELEMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLFOREST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXMLSEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXMLTRANSFORM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\STX6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKACCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aACCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQADMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nADMINISTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKADVISE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAFTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAGENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALL_ROWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aANALYZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tANCILLARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXANY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aARCHIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nARCHIVELOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXASC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tASSERTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tASSOCIATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tATTRIBUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nATTRIBUTES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAUDIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAUTHENTICATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAUTHID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAUTHORIZATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAUTOALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAUTOEXTEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAUTOMATIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBACKUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBECOME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBEFORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBEHALF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBINDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITMAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBLOCK_RANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBODY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBOTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBOUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBREAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBROADCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBTITLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBUFFER_POOL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBUILD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBULK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCACHE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICACHE_INSTANCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCANCEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCASCADE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCATEGORY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCHAINED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCHECK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCHECKPOINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCHILD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHOOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCHUNK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLEAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMCLOSE_CACHED_OPEN_CURSORS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCLUSTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCOLUMN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOLUMNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCOLUMN_VALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCOMMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCOMMITTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCOMPATIBILITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMPILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCOMPLETE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICOMPOSITE_LIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCOMPRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMPUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONNECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCONNECT_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONSIDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCONSISTENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONSTANT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCONSTRAINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCONSTRAINTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCONTAINER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONTAINS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONTENTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONTINUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCONTROLFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCPU_PER_CALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICPU_PER_SESSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCREATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNCREATE_STORED_OUTLINES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCROSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCUBE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCURRENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCURSOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCYCLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDANGLING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATABASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATAFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDATAFILES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDBA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDEBUG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDECLARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFAULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFERRABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDEFERRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFINER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDEGREE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDELETE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDEMAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDESC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDETERMINES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDICTIONARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDIMENSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDIRECTORY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDISASSOCIATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDISCONNECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDISKGROUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDISMOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDISTINCT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDISTRIBUTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOMAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDROP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDYNAMIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEACH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEMPTY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aENFORCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQENTRY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKESCAPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bESTIMATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEVENTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCEPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEXCEPTIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEXCHANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCLUDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCLUSIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXECUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXISTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXPIRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPLAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXPLOSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTENDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXTENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTENTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEXTERNALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFAILED_LOGIN_ATTEMPTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFILTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFIRST_ROWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFLAGGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFLASHBACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLUSH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFOLLOWING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFORCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFOREIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFREELIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFREELISTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFRESH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFUNCTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFUNCTIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGENERATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGLOBAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGLOBALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGLOBAL_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGRANT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGROUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGROUPS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHASH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHASHKEYS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHAVING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHEADER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHEAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHIERARCHY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHOUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIDENTIFIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIDENTIFIER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIDGENERATORS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIDLE_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIMMEDIATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINCLUDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINCREMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vINCREMENTAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINDEXED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINDEXES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINDEXTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nINDEXTYPES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINDICATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINITIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vINITIALIZED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINITIALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINITRANS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINNER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINSTANCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINSTANCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINSTEAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fINTERMEDIATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINTERSECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nINVALIDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tISOLATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIISOLATION_LEVEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJAVA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJOIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTKEEP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXKEY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTKILL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLABEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLAYER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLEADING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLEFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLEVEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLIBRARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLINK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOCAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLOCATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLOCKED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLOGFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLOGGING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLOGICAL_READS_PER_CALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMLOGICAL_READS_PER_SESSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLOGOFF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOGON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMANAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMANAGED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMANAGEMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMASTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMATERIALIZED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMAXARCHLOGS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMAXDATAFILES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMAXEXTENTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMAXINSTANCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMAXLOGFILES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMAXLOGHISTORY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMAXLOGMEMBERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMAXSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMAXTRANS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMAXVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMEMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMERGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMETHOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMINEXTENTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMINIMIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMINIMUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMINUS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMINUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMINVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODIFY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMONITORING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMOVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMOVEMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMTS_DISPATCHERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMULTISET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNAMED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNATURAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNEEDED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNESTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINESTED_TABLE_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNETWORK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNEVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNLS_CALENDAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENLS_CHARACTERSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLS_COMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNLS_CURRENCY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINLS_DATE_FORMAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1NLS_DATE_LANGUAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENLS_ISO_CURRENCY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLS_LANG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNLS_LANGUAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNLS_NUMERIC_CHARACTERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLS_SORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1NLS_SPECIAL_CHARS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNLS_TERRITORY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXNO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNOARCHIVELOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOAUDIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOCACHE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOCOMPRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOCYCLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOFORCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNOLOGGING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOMAXVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOMINIMIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOMINVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNOMONITORING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOORDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOOVERRIDE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOPARALLEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNORELY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNORESETLOGS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNOREVERSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNORMAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNOSEGMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNOSORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOTHING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNOVALIDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNOWAIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNULLS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOBJNO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOBJNO_REUSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOFF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOFFLINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOIDINDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOLD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKONLINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPCODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOPEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOPERATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOPTIMAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOPTIMIZER_GOAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQORDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fORGANIZATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOUTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOUTLINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOVERFLOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOVERLAPS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOWN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPACKAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPACKAGES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPARALLEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPARAMETERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPARENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPARTITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPARTITIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPARTITION_HASH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPARTITION_RANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPASSWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PASSWORD_GRACE_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PASSWORD_LIFE_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PASSWORD_LOCK_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PASSWORD_REUSE_MAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PASSWORD_REUSE_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANPASSWORD_VERIFY_FUNCTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPCTFREE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPCTINCREASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPCTTHRESHOLD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPCTUSED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPCTVERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPERCENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPERMANENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPLAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPLSQL_DEBUG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPOST_TRANSACTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPREBUILT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPRECEDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPREPARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRESENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPRESERVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPREVIOUS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIMARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPRIOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIVATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPRIVATE_SGA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPRIVILEGES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPROFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPUBLIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPURGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQUERY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQUEUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQUOTA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRANDOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRBA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQREADS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREBUILD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RECORDS_PER_BLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRECOVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRECOVERABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRECOVERY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRECYCLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREDUCED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREFERENCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREFERENCING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREFRESH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRELY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRENAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREPLACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRESET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRESETLOGS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRESIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRESOLVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRESOLVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRESOURCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRESTRICT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRESTRICTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRESUME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRETURNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQREUSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREVERSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREVOKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRIGHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTROLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQROLES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bROLLBACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROLLUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXROW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROWNUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTROWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSAMPLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSAVEPOINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSCAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSCAN_INSTANCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSCN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSCOPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSD_ALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSD_INHIBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSD_SHOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSEGMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSEG_BLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEG_FILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSELECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSELECTIVITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSERIALIZABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSERVERERROR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSESSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SESSIONS_PER_USER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSESSION_CACHED_CURSORS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSHARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSHARED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSHARED_POOL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSHRINK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSHUTDOWN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSINGLETASK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSKIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKSKIP_UNUSABLE_INDEXES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSNAPSHOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSOME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSOURCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSPECIFICATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSPLIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSQL_TRACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSTANDBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTART\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSTARTUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSTATEMENT_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTATIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSTATISTICS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSTOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSTORAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSTRUCTURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSUBMULTISET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSUBPARTITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSUBPARTITIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSUCCESSFUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSUMMARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSUPPLEMENTAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSUSPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSWITCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSYNONYM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSDBA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSYSOPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSYS_OP_BITVEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSYS_OP_ENFORCE_NOT_NULL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISYS_OP_NOEXPAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSYS_OP_NTCIMG$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTABLES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTABLESPACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTABLESPACE_NO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTABNO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTEMPFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTEMPORARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTHE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTHREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTHROUGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTIMEOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTIMEZONE_HOUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITIMEZONE_MINUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTIME_ZONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTOPLEVEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTRACING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRAILING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTRANSACTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTRANSITIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTRIGGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRIGGERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRUNCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTYPES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nUNARCHIVED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNBOUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNBOUNDED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTUNDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNIFORM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNIQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNLIMITED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUNRECOVERABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUNUSABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNUSED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUPDATABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUPDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUPD_INDEXES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUPPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUSAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXUSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUSER_DEFINED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3USE_STORED_OUTLINES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUSING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVALIDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVALIDATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVALUES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVIEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWHENEVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHERE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWITHOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBETWEEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLIKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aANYDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nANYDATASET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aANYTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBINARY_DOUBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBINARY_FLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBINARY_INTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCHARACTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDBURITYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDECIMAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOUBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHTTPURITYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLONG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMLSLABEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMONTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNATIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNCLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNUMERIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNVARCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOBJECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPLS_INTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPRECISION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRAW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQROWID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSECOND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSINGLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSMALLINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOURIFACTORYTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aURITYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUROWID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVARCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVARCHAR2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVARYING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aXMLTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYEAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTZONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSQL*Plus remark directive\SO\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\STX6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQadmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nadminister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKadvise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQagent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ball_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ballocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanalyze\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tancillary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aarchive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\narchivelog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tassertion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tassociate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaudit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauthenticated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKauthid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauthorization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fautoallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautoextend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tautomatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbackup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbecome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbefore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbehalf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vblock_range\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbroadcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbuffer_pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbuild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbulk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcache\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcache_instances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcancel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acascade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcategory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achained\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncheckpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchoose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMclose_cached_open_cursors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcolumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcolumn_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acolumns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcommitted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcompatibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcomposite_limit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcompress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconnect_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconsider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconsistent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconstraint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstraints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcontainer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcpu_per_call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcpu_per_session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcreate_stored_outlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcross\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdangling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatafile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdatafiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeferrable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdeferred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefiner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdegree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdemand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdesc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndetermines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdimension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisassociate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndisconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdiskgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdismount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdistributed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aenforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bestimate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKevents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texcluding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texclusive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexecute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexpire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexplain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texplosion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexternally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKfailed_login_attempts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfirst_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflagger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tflashback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfollowing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreelists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgenerated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglobal_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglobally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgrant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhashkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTheap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thierarchy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nidentified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nidentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fidgenerators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tidle_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timmediate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tincluding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tincrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vincremental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aindexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aindexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tindextype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nindextypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tindicator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainitial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinitialized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinitially\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binitrans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fintermediate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tintersect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisolation_level\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aleading\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alocator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogging\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNlogical_reads_per_call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlogical_reads_per_session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmanage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amanaged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmanagement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaterialized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaxarchlogs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaxdatafiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaxextents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaxinstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaxlogfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmaxloghistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmaxlogmembers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaxsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxtrans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nminextents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminimum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmonitoring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImts_dispatchers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKneeded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnested\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInested_table_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnls_calendar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnls_characterset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnls_comp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnls_currency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInls_date_format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1nls_date_language\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnls_iso_currency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnls_lang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnls_language\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnls_numeric_characters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnls_sort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1nls_special_chars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnls_territory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnoarchivelog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoaudit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anocache\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnocompress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anocycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnologging\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnomaxvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnominimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnominvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnomonitoring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnooverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnoparallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnorely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnoresetlogs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnoreverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnosegment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnosort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnovalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnowait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnulls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQobjno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vobjno_reuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoffline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boidindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKonline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoptimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOoptimizer_goal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\forganization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQouter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoutline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverlaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackages\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nparameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpartition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpartition_hash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpartition_range\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npartitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3password_grace_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2password_life_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2password_lock_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2password_reuse_max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3password_reuse_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANpassword_verify_function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apctfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpctincrease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpctthreshold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apctused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npctversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apercent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpermanent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTplan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vplsql_debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpost_transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprebuilt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpreceding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprepare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apresent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpreserve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprevious\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprimary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprivate_sga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprivilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprivileges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpurge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqueue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquota\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arebuild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1records_per_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arecover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrecoverable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brecovery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arecycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areduced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreferencing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arefresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tresetlogs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aresolve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresolver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrestricted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treturning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrevoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arewrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQroles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brollback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrollup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrownum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsavepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOscan_instances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKschema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsd_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsd_inhibit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asd_show\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tseg_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bseg_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asegment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vselectivity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fserializable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vservererror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsession_cached_cursors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1sessions_per_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshared_pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshrink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshutdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsingletask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTskip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKskip_unusable_indexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsnapshot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rspecification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsql_trace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astandby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astartup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstatement_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatistics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubmultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubpartition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsubpartitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsuccessful\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asummary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupplemental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asynonym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsys_op_bitvec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsys_op_enforce_not_null$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsys_op_noexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsys_op_ntcimg$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysdba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysoper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntablespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtablespace_no\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtabno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btempfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttemporary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXthe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKthread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\athrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttime_zone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtimezone_hour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItimezone_minute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btoplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atracing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btrailing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtransaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftransitional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btriggers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunarchived\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunbounded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTundo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunlimited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\runrecoverable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunusable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vupd_indexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tupdatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuppper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3use_stored_outlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuser_defined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvalidation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhenever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awithout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abetween\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*+-/<=>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH!=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH~=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH^=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH..\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\210\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nadd_months\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\basciistr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXavg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbin_to_num\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchartorowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acollect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconvert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcorr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcorr_k\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcorr_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcovar_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncovar_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcume_dist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1current_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndbtimezone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdecompose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndense_rank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQderef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nempty_blob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nempty_clob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexistsnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fextractvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfirst_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrom_tz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgreatest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgroup_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgrouping_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhextoraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainitcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinstrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blast_day\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlast_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alengthb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlnnvl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlocaltimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQltrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmake_ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmedian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmonths_between\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnanvl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnew_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnext_day\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4nls_charset_decl_len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnls_charset_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnls_charset_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnls_initcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnls_lower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnls_upper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anlssort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQntile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnullif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInumtodsinterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInumtoyminterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnvl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnvl2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bora_hash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nora_rowscn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpercent_rank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpercentile_cont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpercentile_disc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpowermultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSpowermultiset_by_cardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npresentnnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpresentv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIratio_to_report\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brawtohex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trawtonhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breftohex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fregexp_instr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vregexp_like\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOregexp_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rregexp_substr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregr_avgx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregr_avgy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregr_count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOregr_intercept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aregr_r2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregr_slope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_sxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_sxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_syy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tremainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrow_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrowidtochar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frowidtonchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEscn_to_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsessiontimezone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asoundex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_binomial_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstats_crosstab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstats_f_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstats_ks_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstats_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstats_mw_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_one_way_anova\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2stats_t_test_indep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_t_test_indepu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstats_t_test_one\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_t_test_paired\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstats_wsr_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstddev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstddev_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstddev_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asubstrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sys_connect_by_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsys_context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsys_dburigen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsys_extract_utc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsys_guid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsys_typeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsys_xmlagg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsys_xmlgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsystimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtimestamp_to_scn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEto_binary_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIto_binary_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_clob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rto_dsinterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKto_lob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rto_multi_byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bto_nchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bto_nclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tto_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOto_single_byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fto_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIto_timestamp_tz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rto_yminterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranslate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtreat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttz_offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunistr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tupdatexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auserenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avar_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvar_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwidth_bucket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxmlagg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxmlcolattval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxmlelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlforest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxmlsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxmltransform\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanydata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nanydataset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbinary_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbinary_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObinary_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdburitype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhttpuritype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmlslabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnvarchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpls_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsecond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsingle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmallint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOurifactorytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auritype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKurowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvarchar2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmltype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzone\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULO%(?:bulk_(?:exceptions|rowcount)|found|isopen|notfound|rowcount|rowtype|type)\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString literal\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUser-defined identifier\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(:|&&?)\\w+\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@@?[^@ \\t\\r\\n]\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"SQL*Plus directive to include file\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"SQL*Plus directive to include file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"SQL*Plus directive to include file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSQL*Plus remark directive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSQL*Plus remark directive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH\\'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK&&?\\w+\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH''\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUser-defined identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUser-defined identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"Yury Lebedev (yurylebedev@mail.ru)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.sql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.SQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.DDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
